cmoncrawl.processor.pipeline.streamer.StreamerDummy.\_\_init\_\_
================================================================

.. currentmodule:: cmoncrawl.processor.pipeline.streamer

.. automethod:: StreamerDummy.__init__